@@ -48,7 +48,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.67'; # VERSION
+our $VERSION = '1.68'; # VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -70,7 +70,6 @@ our $VERSION = '1.67'; # VERSION
     Bourso
     BVB
     CSE
-    CMBChina
     Comdirect
     Consorsbank
     Currencies
@@ -102,6 +101,7 @@ our $VERSION = '1.67'; # VERSION
     TSP
     TwelveData
     Union
+		USBonds
     XETRA
     YahooJSON
     YahooWeb
@@ -610,7 +610,7 @@ sub fetch {
     unless ($ENV{"FQ_NOCOUNT"}) {
       # Temporary Counting - not concerned about return code
       my $COUNT_URL =
-        'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $VERSION . '&' . $method;
+        'http://www.panix.com/~hd-fxsts/finance-quote.html?fqversion=' . $VERSION . '&fqmethod=' . $method;
       my $count_ua = LWP::UserAgent->new(timeout => 10);
       my $count_response = $count_ua->head($COUNT_URL);
 
@@ -1291,24 +1291,24 @@ and pass method specific parameters.
 
 =over
 
-=item C<timeout => T> sets the web request timeout to C<T> seconds
+=item C<timeout =E<gt> T> sets the web request timeout to C<T> seconds
 
-=item C<failover => B> where C<B> is a boolean value indicating if failover in
+=item C<failover =E<gt> B> where C<B> is a boolean value indicating if failover in
 fetch is permitted
 
-=item C<fetch_currency => C> sets the desired currency code to C<C> for fetch
+=item C<fetch_currency =E<gt> C> sets the desired currency code to C<C> for fetch
 results
 
-=item C<currency_rates => H> configures the order currency rate modules are
+=item C<currency_rates =E<gt> H> configures the order currency rate modules are
 consulted for exchange rates and currency rate module options
 
-=item C<required_labels => A> sets the required labels for fetch results to
+=item C<required_labels =E<gt> A> sets the required labels for fetch results to
 array C<A>
 
-=item C<<ModuleName>> as a string is the name of a specific
+=item C<ModuleName> as a string is the name of a specific
 Finance::Quote::Module to load
 
-=item C<<methodname> => H> passes hash C<H> to methodname during fetch to 
+=item C<methodname =E<gt> H> passes hash C<H> to methodname during fetch to 
 configure the method
 
 =back
@@ -1327,7 +1327,7 @@ modules. Note that the FQ_LOAD_QUOTELET environment variable must begin with
 '-defaults' if you wish the default modules to be loaded.
 
 Method names correspond to the Perl module in the Finance::Quote module space.
-For example, C<Finance::Quote->new('ASX')> will load the module
+For example, C<Finance::Quote-E<gt>new('ASX')> will load the module
 Finance::Quote::ASX, which provides the method "asx".
 
 Some methods require API keys or have unique options. Passing 'method => HASH'
@@ -1715,7 +1715,6 @@ http://www.gnucash.org/
   Finance::Quote::CSE,
   Finance::Quote::Comdirect,
   Finance::Quote::Consorsbank,
-  Finance::Quote::CMBChina,
   Finance::Quote::Currencies,
   Finance::Quote::Deka,
   Finance::Quote::FinanceAPI,
@@ -1743,6 +1742,7 @@ http://www.gnucash.org/
   Finance::Quote::TreasuryDirect,
   Finance::Quote::TwelveData,
   Finance::Quote::Union,
+  Finance::Quote::USBonds,
   Finance::Quote::YahooJSON,
   Finance::Quote::YahooWeb,
   Finance::Quote::XETRA,
