@@ -16,6 +16,10 @@
 #    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #    02110-1301, USA
 
+# 2025-12-19: sleep_before_query uncommented. Set its parameters
+#             to 1 query every 2 seconds. Error message from AV
+#             indicates they are limiting free/basic use to one
+#             query per second.
 # 2024-04-07: Commented call to sleep_before_query in get_content
 #             subroutine. AlphaVantage is not throttling API calls,
 #             but limits usage with free API key to 25 per day.
@@ -29,14 +33,14 @@ use strict;
 use JSON qw( decode_json );
 use HTTP::Request::Common;
 
-our $VERSION = '1.67'; # VERSION
+our $VERSION = '1.68'; # VERSION
 
 # Alpha Vantage recommends that API call frequency does not extend far
 # beyond ~1 call per second so that they can continue to deliver
 # optimal server-side performance:
 #   https://www.alphavantage.co/support/#api-key
 our @alphaqueries=();
-my $maxQueries = { quantity =>5 , seconds => 60}; # no more than x
+my $maxQueries = { quantity =>1 , seconds => 2}; # no more than x
                                                   # queries per y
                                                   # seconds, based on
                                                   # https://www.alphavantage.co/support/#support
@@ -214,7 +218,7 @@ sub alphavantage {
             . $ticker;
 
         my $get_content = sub {
-            # sleep_before_query();
+            sleep_before_query();
             my $time=int(time()-$launch_time);
             # print STDERR "Query at:".$time."\n";
             $reply = $ua->request( GET $url);
