@@ -31,7 +31,7 @@ use HTML::TreeBuilder;
 use constant DEBUG => $ENV{DEBUG};
 use if DEBUG, 'Smart::Comments', '###';
 
-our $VERSION = '1.67'; # VERSION
+our $VERSION = '1.68'; # VERSION
 
 our $DISPLAY    = 'MarketWatch';
 our $FEATURES   = {};
@@ -68,13 +68,23 @@ sub marketwatch {
   my (%info, $tree, $url, $reply);
   my $ua = $quoter->user_agent();
 
+  $ua->agent("Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/115.0.0.0 Safari/537.36");
+
   my @ua_headers = (
-    'User-Agent' => 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/103.0.0.0 Safari/537.36',
-    'Accept' => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
-    'Accept-Encoding' => 'gzip, deflate, sdch',
-    'Accept-Language' => 'en-US,en;q=0.8',
+    'Accept' => 'text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,*/*;q=0.8',
+    'Accept-Language' => 'en-US,en;q=0.9',
+    'Accept-Encoding' => 'gzip, deflate, br',
+    'Connection' => 'keep-alive',
+    'Upgrade-Insecure-Requests' => '1',
+    'Sec-Fetch-Dest' => 'document',
+    'Sec-Fetch-Mode' => 'navigate',
+    'Sec-Fetch-Site' => 'none',
+    'Sec-Fetch-User' => '?1',
   );
 
+  # Enable cookie handling (websites often check if you can store cookies)
+  $ua->cookie_jar({});
+
   foreach my $stock (@stocks) {
 
     $url   = $MW_URL . $stock;
