@@ -48,7 +48,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.65'; # VERSION
+our $VERSION = '1.68'; # VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -66,7 +66,6 @@ our $VERSION = '1.65'; # VERSION
     ASX
     AlphaVantage
     BSEIndia
-    Bloomberg
     BorsaItaliana
     Bourso
     BVB
@@ -82,7 +81,6 @@ our $VERSION = '1.65'; # VERSION
     FTfunds
     GoldMoney
     GoogleWeb
-    HU
     IndiaMutual
     MarketWatch
     MorningstarCH
@@ -91,21 +89,19 @@ our $VERSION = '1.65'; # VERSION
     NSEIndia
     NZX
     OnVista
-    Oslobors
-    SEB
     SIX
     Sinvestor
     StockData
     Stooq
+    SwissFundData
     TesouroDireto
-    Tiaacref
     TMX
     Tradegate
     TreasuryDirect
-    Troweprice
     TSP
     TwelveData
     Union
+		USBonds
     XETRA
     YahooJSON
     YahooWeb
@@ -114,8 +110,7 @@ our $VERSION = '1.65'; # VERSION
 
 @ISA    = qw/Exporter/;
 @EXPORT = ();
-@EXPORT_OK = qw/troweprice asx tiaacref
-                currency_lookup/;
+@EXPORT_OK = qw/asx currency_lookup/;
 @EXPORT_TAGS = ( all => [@EXPORT_OK]);
 
 $USE_EXPERIMENTAL_UA = 0;
@@ -606,12 +601,16 @@ sub fetch {
   }
 
   {
+    # Setting no critic to avoid Stricture disabled failure
+    # in t/04-critic.t
+    ## no critic
     no strict 'vars';
     our $VERSION = '0.00' unless defined $VERSION;
+    ## use critic
     unless ($ENV{"FQ_NOCOUNT"}) {
       # Temporary Counting - not concerned about return code
       my $COUNT_URL =
-        'http://www.panix.com/~hd-fxsts/finance-quote.html?' . $VERSION . '&' . $method;
+        'http://www.panix.com/~hd-fxsts/finance-quote.html?fqversion=' . $VERSION . '&fqmethod=' . $method;
       my $count_ua = LWP::UserAgent->new(timeout => 10);
       my $count_response = $count_ua->head($COUNT_URL);
 
@@ -1292,24 +1291,24 @@ and pass method specific parameters.
 
 =over
 
-=item C<timeout => T> sets the web request timeout to C<T> seconds
+=item C<timeout =E<gt> T> sets the web request timeout to C<T> seconds
 
-=item C<failover => B> where C<B> is a boolean value indicating if failover in
+=item C<failover =E<gt> B> where C<B> is a boolean value indicating if failover in
 fetch is permitted
 
-=item C<fetch_currency => C> sets the desired currency code to C<C> for fetch
+=item C<fetch_currency =E<gt> C> sets the desired currency code to C<C> for fetch
 results
 
-=item C<currency_rates => H> configures the order currency rate modules are
+=item C<currency_rates =E<gt> H> configures the order currency rate modules are
 consulted for exchange rates and currency rate module options
 
-=item C<required_labels => A> sets the required labels for fetch results to
+=item C<required_labels =E<gt> A> sets the required labels for fetch results to
 array C<A>
 
-=item C<<ModuleName>> as a string is the name of a specific
+=item C<ModuleName> as a string is the name of a specific
 Finance::Quote::Module to load
 
-=item C<<methodname> => H> passes hash C<H> to methodname during fetch to 
+=item C<methodname =E<gt> H> passes hash C<H> to methodname during fetch to 
 configure the method
 
 =back
@@ -1328,7 +1327,7 @@ modules. Note that the FQ_LOAD_QUOTELET environment variable must begin with
 '-defaults' if you wish the default modules to be loaded.
 
 Method names correspond to the Perl module in the Finance::Quote module space.
-For example, C<Finance::Quote->new('ASX')> will load the module
+For example, C<Finance::Quote-E<gt>new('ASX')> will load the module
 Finance::Quote::ASX, which provides the method "asx".
 
 Some methods require API keys or have unique options. Passing 'method => HASH'
@@ -1709,7 +1708,6 @@ http://www.gnucash.org/
   Finance::Quote::AEX,
   Finance::Quote::ASEGR,
   Finance::Quote::ASX,
-  Finance::Quote::Bloomberg,
   Finance::Quote::BorsaItaliana,
   Finance::Quote::BSEIndia,
   Finance::Quote::Bourso,
@@ -1726,7 +1724,6 @@ http://www.gnucash.org/
   Finance::Quote::FTfunds,
   Finance::Quote::GoldMoney,
   Finance::Quote::GoogleWeb,
-  Finance::Quote::HU,
   Finance::Quote::IndiaMutual,
   Finance::Quote::MarketWatch,
   Finance::Quote::MorningstarCH,
@@ -1735,21 +1732,20 @@ http://www.gnucash.org/
   Finance::Quote::NSEIndia,
   Finance::Quote::NZX,
   Finance::Quote::OnVista,
-  Finance::Quote::Oslobors,
-  Finance::Quote::SEB,
   Finance::Quote::SIX,
   Finance::Quote::StockData,
   Finance::Quote::Stooq,
+  Finance::Quote::SwissFundData,
   Finance::Quote::TSP,
   Finance::Quote::TMX,
-  Finance::Quote::Tiaacref,
   Finance::Quote::TesouroDireto,
   Finance::Quote::TreasuryDirect,
-  Finance::Quote::Troweprice,
   Finance::Quote::TwelveData,
   Finance::Quote::Union,
+  Finance::Quote::USBonds,
   Finance::Quote::YahooJSON,
   Finance::Quote::YahooWeb,
+  Finance::Quote::XETRA,
   Finance::Quote::ZA
 
 You should have received the Finance::Quote hacker's guide with this package.
